@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Result;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Contains the result of a JSON Schema evaluation
 
-our $VERSION = '0.546';
+our $VERSION = '0.547';
 
 use 5.020;
 use Moo;
@@ -40,13 +40,19 @@ has valid => (
 sub result { shift->valid } # backcompat only
 
 has exception => (
-  is => 'rw',
+  is => 'ro',
   isa => InstanceOf['JSON::PP::Boolean'],
   coerce => sub { $_[0] ? JSON::PP::true : JSON::PP::false },
   lazy => 1,
   default => sub { any { $_->exception } $_[0]->errors },
 );
 
+has mode => (
+  is => 'ro',
+  isa => Enum[qw(traverse evaluate)],
+  default => 'evaluate',
+);
+
 has $_.'s' => (
   is => 'bare',
   isa => ArrayRef[InstanceOf['JSON::Schema::Modern::'.ucfirst]],
@@ -171,7 +177,13 @@ sub combine ($self, $other, $swap) {
   );
 }
 
-sub stringify ($self) { $self->error_count ? join("\n", $self->errors) : 'valid' }
+sub stringify ($self) {
+  $self->error_count
+    ? ($self->mode eq 'traverse'
+        ? join("\n", map +('at \''.$_->keyword_location.'\': '.$_->error), $self->errors)
+        : join("\n", map +('at \''.$_->instance_location.'\': '.$_->error), $self->errors)
+    ) : 'valid'
+}
 
 sub TO_JSON ($self) {
   $self->format($self->output_format);
@@ -201,7 +213,7 @@ JSON::Schema::Modern::Result - Contains the result of a JSON Schema evaluation
 
 =head1 VERSION
 
-version 0.546
+version 0.547
 
 =head1 SYNOPSIS
 
@@ -243,6 +255,10 @@ appended to those of the first).
 
 A boolean. Indicates whether validation was successful or failed.
 
+=head2 mode
+
+Indicates whether the result was produced during the C<traverse> or C<evaluate> phase of execution.
+
 =head2 errors
 
 Returns an array of L<JSON::Schema::Modern::Error> objects.
